from setuptools import setup, find_packages


setup(
    name='testingrangekeeper2',
    version='0.1',
    author="Muhammad H Ali",
    author_email='6hassan@gmail.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    keywords='example project',
    install_requires=[],

)